@@ -279,9 +279,10 @@ def pytest_generate_tests(metafunc):
 
 
 def pytest_collection_modifyitems(items):
+    # 过滤掉不在收集范围的case
+    items = [item for item in items if getattr(item, "callspec", None)]
     # 重新排序
     new_items = sort(items)
-    # Demo: new_items = [items[0],items[2],items[1],items[3]]
     items[:] = new_items
     for item in items:
         # 获取mark标记
@@ -292,6 +293,8 @@ def pytest_collection_modifyitems(items):
                 item.add_marker(mark)
 
 
+
+
 def pytest_collection_finish(session):
     """获取最终排序后的 items 列表"""
     logger.info(f"共收集到 {len(session.items)} 个测试用例")
@@ -800,11 +803,9 @@ def sort(case_items):
         # 生成每个组当前的索引
         ori_name_temp = None
         ori_name_list = []
-
         for item in non_custom_scope_items:
             clase_id = item.cls.__name__
             original_name = item.originalname
-
             if ori_name_temp is None or ori_name_temp == original_name:
                 ori_name_temp = original_name
                 case_suite_num += 1
