@@ -139,8 +139,14 @@ class MysqlDB:
 
     @staticmethod
     def custom_serializer(obj):
-        if isinstance(obj, datetime):
-            return obj.strftime('%Y-%m-%d %H:%M:%S')  # 转换时间格式
-        elif isinstance(obj, Decimal):
-            return float(obj)  # 转换 Decimal 为 float
-        raise TypeError(f"Type {type(obj)} not serializable")
\ No newline at end of file
+        try:
+            if isinstance(obj, datetime):
+                return obj.strftime('%Y-%m-%d %H:%M:%S')
+            elif isinstance(obj, Decimal):
+                return float(obj)
+            elif isinstance(obj, bytes):
+                return obj.decode(errors='ignore', encoding='utf-8')
+            # 不处理的类型：直接返回原对象
+            return obj
+        except Exception:
+            return obj
\ No newline at end of file
