@@ -9,7 +9,7 @@ from config.settings import AVAILABLE_ENVS, ENV_CONFIG
 class PaymentType(Enum):
     """支付类型枚举"""
     DEPOSIT = 0  # 入金
-    WITHDRAWAL = 1  # 出金
+    WALLET_SCANNING = 1  # 出金
     CHECKOUT = 2  # 结账
 
 
@@ -22,6 +22,7 @@ class RiskLevel(Enum):
     MEDIUM_HIGH = 3  # 中高风险
     HIGH = 4  # 高风险
     SEVERE = 5  # 严重风险
+    PENDING_KYT = 6  # 严重风险
 
 
 @unique
